@@ -2,14 +2,15 @@
 # encoding: utf-8
 
 __author__ = "ChenyangGao <https://chenyanggao.github.io>"
-__version__ = (0, 0, 2)
+__version__ = (0, 0, 3)
 __all__ = [
     "SupportsRead", "SupportsWrite", "bio_chunk_iter", "bio_chunk_async_iter", 
-    "bio_skip_iter", "bio_skip_async_iter", "bio_skip_bytes", "bio_skip_bytes_async"
+    "bio_skip_iter", "bio_skip_async_iter", "bio_skip_bytes", "bio_skip_bytes_async", 
+    "bytes_iter_to_reader", "bytes_iter_to_reader_async", 
 ]
 
 from asyncio import to_thread
-from collections.abc import Awaitable
+from collections.abc import Awaitable, AsyncIterable, Iterable
 from functools import update_wrapper
 from inspect import isawaitable, iscoroutinefunction
 from collections.abc import AsyncIterator, Callable, Iterator
@@ -262,3 +263,51 @@ async def bio_skip_bytes_async(
     async for _ in bio_skip_async_iter(bio, size, chunksize, callback=callback):
         pass
 
+
+def bytes_iter_to_reader(it: Iterable[bytes | bytearray], /) -> SupportsRead[bytes]:
+    get_next = iter(it).__next__
+    unconsumed = bytearray(b"")
+    def read(n=-1):
+        nonlocal unconsumed
+        if n == 0:
+            return b""
+        try:
+            if n < 0:
+                while True:
+                    unconsumed.extend(get_next())
+            else:
+                while n > len(unconsumed):
+                    unconsumed.extend(get_next())
+                b, unconsumed = unconsumed[:n], unconsumed[n:]
+                return bytes(b)
+        except StopIteration:
+            return bytes(unconsumed)
+    reprs = f"<reader for {it!r}>"
+    return type("reader", (), {"read": staticmethod(read), "__repr__": staticmethod(lambda: reprs)})()
+
+
+def bytes_iter_to_reader_async(it: Iterable[bytes | bytearray] | AsyncIterable[bytes | bytearray], /) -> SupportsRead[bytes]:
+    unconsumed = bytearray(b"")
+    if isinstance(it, AsyncIterable):
+        get_next = aiter(it).__anext__
+    else:
+        sync_next = iter(it).__next__
+        get_next = lambda: to_thread(sync_next)
+    async def read(n=-1):
+        nonlocal unconsumed
+        if n == 0:
+            return b""
+        try:
+            if n < 0:
+                while True:
+                    unconsumed.extend(await get_next())
+            else:
+                while n > len(unconsumed):
+                    unconsumed.extend(await get_next())
+                b, unconsumed = unconsumed[:n], unconsumed[n:]
+                return bytes(b)
+        except StopIteration:
+            return bytes(unconsumed)
+    reprs = f"<reader for {it!r}>"
+    return type("reader", (), {"read": staticmethod(read), "__repr__": staticmethod(lambda: reprs)})()
+
